import { appVersionCode, baseAPIUrl } from '@/http/configAPI.js'
import { getChromeStorage } from '@/uilts/chromeExtension.js'

export async function fetchTtwitterRequestToken() {
    let storage_mid = await getChromeStorage('mid') || ''
    const { mid } = storage_mid || {}
    return new Promise(function (resolve, reject) {
        let _url = `${baseAPIUrl}/user/twitterRequestToken`
        fetch(_url, {
            method: 'POST', // or 'PUT'
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                "baseInfo": {
                    appVersionCode,
                    mid
                },
                "params": {
                    "oauthCallback": "oob"
                }
            }),
        })
            .then(response => response.json())
            .then(data => {
                resolve(data);
            })
            .catch((error) => {
                reject(error);
            });
    })
}

export async function fetchTwitterLogin(oauthToken, oauthVerifier, receivedIds = []) {
    let storage_mid = await getChromeStorage('mid') || ''
    const { mid } = storage_mid || {}
    return new Promise(function (resolve, reject) {
        let _url = `${baseAPIUrl}/user/twitterLogin`
        fetch(_url, {
            method: 'POST', // or 'PUT'
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                "baseInfo": {
                    appVersionCode,
                    mid
                },
                "params": {
                    "oauthToken": oauthToken,
                    "oauthVerifier": oauthVerifier,
                    "receivedIds": receivedIds
                }
            }),
        })
            .then(response => response.json())
            .then(data => {
                resolve(data);
            })
            .catch((error) => {
                reject(error);
            });

    })
}
// 请求推特短链接
export async function fetchTwitterShortUrl(url) {
    return new Promise(function (resolve, reject) {
        fetch(url) // 返回一个Promise对象 
            .then((res) => {
                return res.text() // res.text()是一个Promise对象
            }).then((res) => {
                resolve(res.toString());
            })
    })
}


export async function fetchAllMessageInfo(params = {}) {
    let storage_mid = await getChromeStorage('mid') || ''
    const { accessToken: token = '', uid = '' } = await getChromeStorage('userInfo') || {}
    const { mid } = storage_mid || {};
    return new Promise(function (resolve, reject) {
        if(!token) {
            resolve({});
            return;
        }
        let _url = `${baseAPIUrl}/message/getStat`
        fetch(_url, {
            method: 'POST', 
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                "baseInfo": {
                    appVersionCode,
                    mid,
                    machineCode: mid,
                    token: token,
                    uid,
                    loginUid: uid,
                    appType:1,
                },
                "params": params
            }),
        }).then(response => response.json())
            .then(data => {
                resolve(data);
            })
            .catch((error) => {
                reject(error);
            });
    })
}

export async function fetchReadTaskAllMsg(params = {}) {
    let storage_mid = await getChromeStorage('mid') || ''
    const { accessToken: token = '', uid = '' } = await getChromeStorage('userInfo') || {}
    const { mid } = storage_mid || {};
    return new Promise(function (resolve, reject) {
        if(!token) {
            resolve({});
            return;
        }
        let _url = `${baseAPIUrl}/message/readAllMsgByType`
        fetch(_url, {
            method: 'POST', 
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                "baseInfo": {
                    appVersionCode,
                    mid,
                    machineCode: mid,
                    token: token,
                    uid,
                    loginUid: uid,
                    appType:1,
                },
                "params": params
            }),
        }).then(response => response.json())
            .then(data => {
                resolve(data);
            })
            .catch((error) => {
                reject(error);
            });
    })
}